FlutterNativeGalleryHeader class

Inheritance

Constructors

FlutterNativeGalleryHeader({Key? key, required String title, required String albumPickerTitle, required String cancelLabel, required String highQualityLabel, required String highQualityTooltip, required FlutterNativeGalleryAlbum? album, required List<FlutterNativeGalleryAlbum> albums, required FlutterNativeGalleryRequestType requestType, required bool showHighQualityToggle, required bool highQualitySelected, required VoidCallback onCancel, required ValueChanged<bool> onHighQualityChanged, required ValueChanged<FlutterNativeGalleryAlbum> onAlbumSelected})
const

Properties

album FlutterNativeGalleryAlbum?
final
albumPickerTitle String
final
albums List<FlutterNativeGalleryAlbum>
final
cancelLabel String
final
hashCode int
The hash code for this object.
no setterinherited
highQualityLabel String
final
highQualitySelected bool
final
highQualityTooltip String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAlbumSelected ValueChanged<FlutterNativeGalleryAlbum>
final
onCancel VoidCallback
final
onHighQualityChanged ValueChanged<bool>
final
requestType FlutterNativeGalleryRequestType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showHighQualityToggle bool
final
title String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited